:mod:`art.defences`
===================
.. automodule:: art.defences

Feature Squeezing
-----------------
.. autoclass:: FeatureSqueezing
   :members:
   :special-members:

Spatial Smoothing
-----------------
.. autoclass:: SpatialSmoothing
   :members:
   :special-members:

Label Smoothing
---------------
.. autoclass:: LabelSmoothing
   :members:
   :special-members:

Adversarial Training
--------------------
.. autoclass:: AdversarialTrainer
   :members:
   :special-members:

.. autoclass:: StaticAdversarialTrainer
   :members:
   :special-members:

Gaussian Data Augmentation
--------------------------
.. autoclass:: GaussianAugmentation
   :members:
   :special-members:

JPEG Compression
----------------
.. autoclass:: JpegCompression
   :members:
   :special-members:

Thermometer Encoding
--------------------
.. autoclass:: ThermometerEncoding
   :members:
   :special-members:

Total Variance Minimization
---------------------------
.. autoclass:: TotalVarMin
   :members:
   :special-members:
